***************************
* File: ecole.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\Second Round\ecole_2e_jour\caisse.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "caisse", replace
codebook, compact
log close

label var plancher "qualit du plancher"
**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "caisse", replace
label define cause 1 `"inscription tardive eleves"', modify

**************************************************
***   Unique identifiers: ID
**************************************************
drop if codecole==.

**************************************************
***   Recode missing values
***************************************************
*    DECODE MISSING VALUES
# d ;
qui mvdecode   rsn_retard , mv(
5=.d);
# d cr;

**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

foreach v of varlist jour  mois annee rsn_retard  solution jour_info mois_info annee_info corresp plus differen cause mont_elv assurance coop_scol sport_sco act_art obligat total restant affiche endroit compta control fourn_cs livre_cs equip_cs frn_enft_cs nourri_cs entret_cs sal_ensg_cs depl_faf_cs depl_aut_cs mnt_elec_cs constr_cs gardien_cs dep_aut1_cs dep_aut2_cs reste_cs {
	gen error01`v' = (caisse_faf == 2 & `v'< . )
}


foreach v of varlist plus differen cause {
	gen error02`v' = (corresp== 1 & `v'< . )
}
gen error03endroit = ( affiche == 2 & endroit< . )

foreach v of varlist  fixe  mnt_fixe typ_fixe rembour levee fourn_fram livre_fram equip_fram enft_fram nourri_fram entre_fram sal_fram depl_faf_fr depl_aut_fr mnt_elec_fr constr_fram gard_fram dep_aut1_fr dep_aut2_fr reste_fram{
	gen error04`v' = (par_fram   == 2 & `v'< . )
}

foreach v of varlist    mnt_fixe typ_fixe {
	gen error05`v' = (fixe  == 2 & `v'< . )
}
foreach v of varlist   man_07-  non_07 {
	gen error06`v' = (cp2_exist  == 2 & `v'< . )
}

drop err*

**************************************************
***  Identify illegal responses
**************************************************
log using "caisse label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
log using "caisse grubbs", replace
preserve
global lab (	cause	fenetre	toit	murs	plancher	non_07	rec_man_07	rec_kit_07	typ_fixe	endroit	plus	solution	rsn_retard	man_07	cp2_exist	kits_07	fram_nat	levee	rembour	fixe	par_fram	control	compta	affiche	corresp	caisse_faf)
global name (  autre1_cs autre2_cs aut1_fram aut2_fram)
drop  $lab $name
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore

**************************************************
***   Reviewing errors and computing responses
**************************************************

 
 foreach v of varlist  restant	 fourn_cs livre_cs	equip_cs	 frn_enft_cs	 nourri_cs 	entret_cs	 sal_ensg_cs	 depl_faf_cs	 depl_aut_cs	 mnt_elec_cs	 constr_cs 	gardien_cs	 dep_aut1_cs	 dep_aut2_cs	 reste_cs	{
	replace `v' = . if codecole== 2132922	|codecole==  2132923|codecole== 	2134121|codecole== 	2134122	|codecole== 2134321|codecole== 	2134322	|codecole== 2134323	|codecole== 2160221	|codecole== 2160222	|codecole== 2160223|codecole== 	2160621	|codecole== 2160622	|codecole== 2160623	|codecole== 2161721	|codecole== 2161722	|codecole== 2161723
}

 foreach v of varlist 	caisse_faf	affiche	endroit	compta	control	fourn_cs	livre_cs	equip_cs	frn_enft_cs	nourri_cs	entret_cs	sal_ensg_cs	depl_faf_cs	depl_aut_cs	mnt_elec_cs	constr_cs	gardien_cs	dep_aut1_cs	dep_aut2_cs	reste_cs																			 {
	replace `v' = . if codecole== 1121622	
}

 foreach v of varlist caisse_faf	fourn_cs	livre_cs	equip_cs	frn_enft_cs	nourri_cs	entret_cs	sal_ensg_cs	depl_faf_cs	depl_aut_cs	mnt_elec_cs	constr_cs	gardien_cs	dep_aut1_cs	dep_aut2_cs	reste_cs	{																						
	replace `v' = . if codecole==	1060921	|codecole==	1060923	|codecole==	1061121	|codecole==	1061122	|codecole==	1061123	|codecole==	1063721	|codecole==	1063722	|codecole==	1063723	|codecole==	1092321	|codecole==	1092322	|codecole==	1092323	|codecole==	1093121	|codecole==	1093122	|codecole==	1093123	|codecole==	1093721	|codecole==	1093722	|codecole==	1093723	|codecole==	1110321	|codecole==	1110322	|codecole==	1110323	|codecole==	1111121	|codecole==	1111122	|codecole==	1111123	|codecole==	1113121	|codecole==	1113122	|codecole==	1113123	|codecole==	1120521	|codecole==	1120522	|codecole==	1120523	|codecole==	1121621	|codecole==	1121623	|codecole==	1125523	|codecole==	1140521	|codecole==	1140522	|codecole==	1140523	|codecole==	1141921	|codecole==	1141922	|codecole==	1141923	|codecole==	1142321	|codecole==	1142322	|codecole==	2040121	|codecole==	2040122	|codecole==	2040123	|codecole==	2041121	|codecole==	2041122	|codecole==	2041123	|codecole==	2041921	|codecole==	2041922	|codecole==	2041923	|codecole==	2050521	|codecole==	2050522	|codecole==	2050523	|codecole==	2050921	|codecole==	2050923	|codecole==	2052721	|codecole==	2052722	|codecole==	2052723	|codecole==	2060121	|codecole==	2060122	|codecole==	2060123	|codecole==	2060321	|codecole==	2060322	|codecole==	2060323	|codecole==	2060721	|codecole==	2060722	|codecole==	2060723	|codecole==	2070321	|codecole==	2070322	|codecole==	2070323	|codecole==	2070521	|codecole==	2070522	|codecole==	2070523	|codecole==	2071321	|codecole==	2071322	|codecole==	2071323	|codecole==	2132921	|codecole==	2134123	|codecole==	2202921	|codecole==	2202922	|codecole==	2202923	|codecole==	2203321	|codecole==	2203322	|codecole==	2203323	|codecole==	2205121	|codecole==	2205122	|codecole==	2205123	|codecole==	3040521	|codecole==	3040522	|codecole==	3040523	|codecole==	3040621	|codecole==	3040622	|codecole==	3040623	|codecole==	3045521	|codecole==	3045522	|codecole==	3045523	|codecole==	3080221	|codecole==	3080222	|codecole==	3080223	|codecole==	3080321	|codecole==	3080322	|codecole==	3080323	|codecole==	3081321	|codecole==	3081322	|codecole==	3081323	|codecole==	3141121	|codecole==	3141122	|codecole==	3141123	|codecole==	3143121	|codecole==	3143122	|codecole==	3143123	|codecole==	3145521	|codecole==	3145522	|codecole==	3145523	|codecole==	4060921	|codecole==	4060922	|codecole==	4060923	|codecole==	4061021	|codecole==	4061022	|codecole==	4061023	|codecole==	4061121	|codecole==	4061122	|codecole==	4061123	|codecole==	4080321	|codecole==	4080322	|codecole==	4080721	|codecole==	4080722	|codecole==	4080723	|codecole==	4081122	|codecole==	4081123	|codecole==	4091121	|codecole==	4091122	|codecole==	4091123	|codecole==	4091221	|codecole==	4091222	|codecole==	4091223	|codecole==	4091421	|codecole==	4091422	|codecole==	4091423	|codecole==	4131522	|codecole==	4130221	|codecole==	4130222	|codecole==	4130223	|codecole==	4131321	|codecole==	4131322	|codecole==	4131323	|codecole==	4131521	|codecole==	4131523	|codecole==	5110121	|codecole==	5110122	|codecole==	5110123	|codecole==	5110721	|codecole==	5110722	|codecole==	5110723	|codecole==	5111921	|codecole==	5111922	|codecole==	5111923	|codecole==	5120921	|codecole==	5120922	|codecole==	5120923	|codecole==	5121521	|codecole==	5121522	|codecole==	5121523	|codecole==	5125521	|codecole==	5125522	|codecole==	5125523	|codecole==	5140221	|codecole==	5140222	|codecole==	5140223	|codecole==	5145521	|codecole==	5145522	|codecole==	5145523	|codecole==	5146621	|codecole==	5146622	|codecole==	5146623	|codecole==	5190121	|codecole==	5190122	|codecole==	5190123	|codecole==	5191721	|codecole==	5191722	|codecole==	5191723	|codecole==	5192521	|codecole==	5192522	|codecole==	5192523
}

 foreach v of varlist par_fram	fixe	typ_fixe	rembour	levee	fourn_fram	livre_fram	equip_fram	enft_fram	nourri_fram	entre_fram	sal_fram	depl_faf_fr	depl_aut_fr	mnt_elec_fr	constr_fram	gard_fram	dep_aut1_fr	dep_aut2_fr	reste_fram	{
	replace `v' = . if codecole==	1120522	|codecole==	2040121	|codecole==	2041122	|codecole==	2041922	|codecole==	2060322	|codecole==	2070321	|codecole==	2071323	|codecole==	2134322	|codecole==	2160221	|codecole==	2160222	|codecole==	2160223	|codecole==	2160622	|codecole==	2160623	|codecole==	2161721	|codecole==	2161722	|codecole==	2161723	|codecole==	4020221	|codecole==	4020223
	}

replace 	par_fram=1 if codecole==7163121

 foreach v of varlist 	rembour	levee	fourn_fram	livre_fram	equip_fram	enft_fram	nourri_fram	entre_fram	sal_fram	depl_faf_fr	depl_aut_fr	mnt_elec_fr	constr_fram	gard_fram	dep_aut1_fr	dep_aut2_fr	reste_fram	 {
	replace `v' = . if codecole==	5111922
	}
	
foreach v of varlist 	levee	fourn_fram	livre_fram	equip_fram	enft_fram	nourri_fram	entre_fram	sal_fram	depl_faf_fr	depl_aut_fr	mnt_elec_fr	constr_fram	gard_fram	dep_aut1_fr	dep_aut2_fr	reste_fram	 {
	replace `v' = . if codecole==2202921 | codecole==2202922
	}
foreach v of varlist 	mnt_fixe	typ_fixe{
	replace `v' = . if codecole==1141922 | codecole==3080322
	}

replace man_07=. if codecole==2202921 | codecole== 2203322 | codecole==3019922  | codecole== 3080221
	
foreach v of varlist 	nb_mlg_07	nb_mat_07	nb_frc_07{
	replace `v' = . if codecole==3019922 | codecole==3080221
	}

replace non_07=. if codecole==	1060923	|codecole==	1113122	|codecole==	1142322	|codecole==	2202921	|codecole==	2203322	|codecole==	3019922	|codecole==	3080221	|codecole==	4080721	|codecole==	4080722	|codecole==	4080723	|codecole==	4081122	|codecole==	4081123	|codecole==	4091121	|codecole==	4091122	|codecole==	4091123	|codecole==	4091221	|codecole==	4091222	|codecole==	5145521




**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\ecole_2e_jour"
log using "caisse codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\ecole_2e_jour"
save "caisse_cleaned_data.dta", replace
