***************************
* File: ecole.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\Second Round\ecole_2e_jour\ecole.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "ecole", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "ecole", replace

label define renvoi_fonc 4 `"cisco"', modify
label define renvoi_fonc 3 `"chef zap"', modify
label define renvoi_fram 4 `"cisco"', modify
label define renvoi_fram 3 `"chef zap"', modify
label define eval_fonc 4 `"cisco"', modify
label define eval_fonc 3 `"chef zap"', modify
label define eval_fram 4 `"cisco"', modify
label define eval_fram 3 `"chef zap"', modify
label define methode 4 `"cisco"', modify
label define methode 3 `"chef zap"', modify
label define livre 4 `"cisco"', modify
label define livre 3 `"chef zap"', modify


**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

gen error01critere = (refus_cp1 == 2 & critere< . )

gen error02nb_vis_cisco = (vis_cisco == 2 & nb_vis_cisco< . )

foreach v of varlist      nb_mb_fram reun_fram nb_parent nb_coge coge_femme {
	gen error03`v' = (fram == 2 & `v'< . )
}
gen error04elec_fonc = (elec == 2 & elec_fonc< . )
gen error05toil_sep = (toilet == 2 & toil_sep< . )
gen error06nb_assis = (assis == 2 & nb_assis< . )
gen error07nb_pleinair = (plein_air == 2 & nb_pleinair< . )

**************************************************
***  Identify other internal coherence issues
**************************************************
	
gen inc01 = ( gar_pre_07+fil_pre_07 != tot_pre_07 & tot_pre_07 !=0 )
gen inc02 = ( gar_cp1_07+fil_cp1_07!= tot_cp1_07 & tot_cp1_07 !=0 & (gar_cp1_07< . & fil_cp1_07< .)  )
gen inc03 = ( gar_cp2_07+fil_cp2_07!= tot_cp2_07 & tot_cp2_07 !=0 & (gar_cp2_07< . & fil_cp2_07< .))
gen inc04 = ( gar_ce_07+fil_ce_07!= tot_ce_07 & tot_ce_07 !=0& (gar_ce_07< . & fil_ce_07< .))
gen inc05 = ( gar_cm1_07+fil_cm1_07!= tot_cm1_07 & tot_cm1_07 !=0& (gar_cm1_07< . & fil_cm1_07< .))
gen inc06 = ( gar_cm2_07+fil_cm2_07!= tot_cm2_07 & tot_cm2_07 !=0& (gar_cm2_07< . & fil_cm2_07< .))

**************************************************
***  Identify illegal responses
**************************************************
log using "ecole label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
log using "ecole grubbs", replace
preserve
global lab (elev_math	elev_fran	elev_malg	diction	sanc_fram3	sanc_fram2	sanc_fram1	sanc_fonc3	sanc_fonc2	sanc_fonc1	reco_fram3	reco_fram2	reco_fram1	reco_fonc3	reco_fonc2	reco_fonc1	unit_reun	prog_ensgt	critere	multigr	normal	plein	mitps	tps_part	refus_cp1	vis_cisco	vis_dren	fram	elec	elec_fonc	bur_dir	biblio	salle_ensgt	infirm	toilet	toil_sep	cantine	sport	eau_pot	assis	plein_air	renvoi_fonc	renvoi_fram	eval_fonc	eval_fram	methode	livre)
global name ( autre1_07 autre2_07)
drop  $lab $name
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore

**************************************************
***   Reviewing errors and computing responses
**************************************************

replace critere=. if codecole==	2041122	|codecole==	2041123	|codecole==	2070323	|codecole==	2132921	|codecole==	2132922	|codecole==	2134123	|codecole==	2134323	|codecole==	4020223	|codecole==	4081122	|codecole==	5110723	|codecole==	5121522	|codecole==	5192522	|codecole==	7163121	|codecole==	7163122	|codecole==	7191923

replace nb_vis_cisco=. if  error02nb_vis_cisco ==1 & nb_vis_cisco== 0
replace vis_cisco=1 if  codecole==2052722 |  codecole==4020222 |  codecole==5192523
replace nb_mb_fram=. if codecole==4020221|  codecole==4080322
replace reun_fram=. if codecole==4020221|  codecole==4080322

foreach v of varlist  nb_parent	nb_coge	coge_femme {
	replace `v' = . if codecole== 4080322
}

replace elec_fonc =. if codecole==	1031721	|codecole==	1060921	|codecole==	1113121	|codecole==	1121621	|codecole==	1121623	|codecole==	1125521	|codecole==	1125522	|codecole==	1125523	|codecole==	1140522	|codecole==	1140523	|codecole==	1141921	|codecole==	1141922	|codecole==	1141923	|codecole==	1142321	|codecole==	1142323	|codecole==	2040121	|codecole==	2040122	|codecole==	2040123	|codecole==	2041121	|codecole==	2041122	|codecole==	2041123	|codecole==	2041921	|codecole==	2041922	|codecole==	2041923	|codecole==	2050521	|codecole==	2050523	|codecole==	2052722	|codecole==	2060121	|codecole==	2060122	|codecole==	2060123	|codecole==	2060321	|codecole==	2060322	|codecole==	2060323	|codecole==	2060721	|codecole==	2060722	|codecole==	2060723	|codecole==	2070321	|codecole==	2070322	|codecole==	2070323	|codecole==	3019927	|codecole==	4020223

replace  toil_sep=. if codecole==	1093722	|codecole==	1111121	|codecole==	1121623	|codecole==	3081321	|codecole==	3143122	|codecole==	4020221	|codecole==	4020222	|codecole==	4020223	|codecole==	4020521	|codecole==	4080721	|codecole==	4091121	|codecole==	4091122	|codecole==	4091221	|codecole==	4091222	|codecole==	4091421	|codecole==	4091422	|codecole==	4091423	|codecole==	5110722	|codecole==	5120922	|codecole==	5140222	|codecole==	5145522	|codecole==	5145523	|codecole==	5146621	|codecole==	5190122	|codecole==	5191721	|codecole==	5191722	|codecole==	5192523	|codecole==	7162721	|codecole==	7162722	|codecole==	7162723	|codecole==	7162922	|codecole==	7162923	|codecole==	7190421	|codecole==	7190422	|codecole==	7190621	|codecole==	7190622

replace  nb_assis=. if codecole==	1030723	|codecole==	1030721	|codecole==	1030722	|codecole==	1031321	|codecole==	1031322	|codecole==	1031323	|codecole==	1031721	|codecole==	1031722	|codecole==	1031723	|codecole==	2060121	|codecole==	2060123	|codecole==	2060321	|codecole==	2060721	|codecole==	2060722	|codecole==	2070322	|codecole==	2071323	|codecole==	3019922	|codecole==	3019923	|codecole==	3019924	|codecole==	3019925	|codecole==	3019926	|codecole==	3019927	|codecole==	3019928	|codecole==	3019929	|codecole==	3080221	|codecole==	3080223	|codecole==	3080321	|codecole==	3081321	|codecole==	3081323	|codecole==	3141121	|codecole==	3141123	|codecole==	3143121	|codecole==	3143122	|codecole==	3143123	|codecole==	3145521	|codecole==	3145522	|codecole==	3145523	|codecole==	4020221	|codecole==	4020522	|codecole==	4020523	|codecole==	4060922	|codecole==	4060923	|codecole==	4061122	|codecole==	4061123	|codecole==	4080322	|codecole==	4080721	|codecole==	4080722	|codecole==	4080723	|codecole==	4081123	|codecole==	4091121	|codecole==	4091122	|codecole==	4091123	|codecole==	4091221	|codecole==	4091422	|codecole==	4130221	|codecole==	4130222	|codecole==	4130223	|codecole==	4131322	|codecole==	4131323	|codecole==	4131521	|codecole==	4131523	|codecole==	5110122	|codecole==	5110721	|codecole==	5110722	|codecole==	5111922	|codecole==	5120922	|codecole==	5121521	|codecole==	5190121	|codecole==	5190122	|codecole==	5190123	|codecole==	5191723	|codecole==	5192522	|codecole==	7162721	|codecole==	7162722	|codecole==	7162723	|codecole==	7162922	|codecole==	7162923	|codecole==	7163121	|codecole==	7163122	|codecole==	7163123	|codecole==	7190421	|codecole==	7190623	|codecole==	7190621	|codecole==	7191922	|codecole==	7191923

replace nb_pleinair=. if codecole==	1030723	|codecole==	1030721	|codecole==	1030722	|codecole==	1031321	|codecole==	1031322	|codecole==	1031323	|codecole==	1031721	|codecole==	1031722	|codecole==	1031723	|codecole==	2050923	|codecole==	2060121	|codecole==	2060122	|codecole==	2060123	|codecole==	2060321	|codecole==	2060322	|codecole==	2060721	|codecole==	2060722	|codecole==	2070321	|codecole==	2070322	|codecole==	2070323	|codecole==	2070523	|codecole==	2071323	|codecole==	2132921	|codecole==	2132922	|codecole==	2132923	|codecole==	2134121	|codecole==	2134122	|codecole==	2134123	|codecole==	2134321	|codecole==	2134322	|codecole==	2134323	|codecole==	2160221	|codecole==	2160222	|codecole==	2160223	|codecole==	2160621	|codecole==	2160622	|codecole==	2160623	|codecole==	2161721	|codecole==	2161722	|codecole==	2161723	|codecole==	2202922	|codecole==	2202923	|codecole==	3019921	|codecole==	3019922	|codecole==	3019923	|codecole==	3019924	|codecole==	3019925	|codecole==	3019926	|codecole==	3019927	|codecole==	3019928	|codecole==	3019929	|codecole==	3080221	|codecole==	3080222	|codecole==	3080223	|codecole==	3080321	|codecole==	3080322	|codecole==	3080323	|codecole==	3081321	|codecole==	3081322	|codecole==	3081323	|codecole==	3141121	|codecole==	3141122	|codecole==	3141123	|codecole==	3143121	|codecole==	3143122	|codecole==	3143123	|codecole==	3145521	|codecole==	3145522	|codecole==	3145523	|codecole==	4020221	|codecole==	4020222	|codecole==	4020521	|codecole==	4020522	|codecole==	4020523	|codecole==	4060921	|codecole==	4060922	|codecole==	4060923	|codecole==	4061021	|codecole==	4061023	|codecole==	4061122	|codecole==	4061123	|codecole==	4080321	|codecole==	4080322	|codecole==	4080721	|codecole==	4080722	|codecole==	4080723	|codecole==	4081122	|codecole==	4081123	|codecole==	4091121	|codecole==	4091122	|codecole==	4091123	|codecole==	4091221	|codecole==	4091222	|codecole==	4091223	|codecole==	4091421	|codecole==	4091422	|codecole==	4091423	|codecole==	4130221	|codecole==	4130222	|codecole==	4130223	|codecole==	4131322	|codecole==	4131323	|codecole==	4131521	|codecole==	4131522	|codecole==	4131523	|codecole==	5110122	|codecole==	5110123	|codecole==	5110721	|codecole==	5110722	|codecole==	5110723	|codecole==	5111922	|codecole==	5111923	|codecole==	5120921	|codecole==	5120922	|codecole==	5120923	|codecole==	5190121	|codecole==	5190122	|codecole==	5190123	|codecole==	5191721	|codecole==	5191722	|codecole==	5191723	|codecole==	5192522	|codecole==	5192523	|codecole==	7162721	|codecole==	7162722	|codecole==	7162922	|codecole==	7162923	|codecole==	7163122	|codecole==	7190421	|codecole==	7190422	|codecole==	7190423	|codecole==	7190623	|codecole==	7190621	|codecole==	7190622	|codecole==	7191922	|codecole==	7191923

replace  tot_cp1_07=	32	if codecole==	1093721
replace  tot_cp1_07=	86	if codecole==	1110323
replace  tot_cp1_07=	42	if codecole==	1141921
replace  tot_cp1_07=	21	if codecole==	2050522
replace  tot_cp1_07=	22	if codecole==	2060122
replace  tot_cp1_07=	45	if codecole==	2070321
replace  tot_cp1_07=	57	if codecole==	3040623
replace  tot_cp1_07=	120	if codecole==	4020222
replace  tot_cp1_07=	39	if codecole==	5110121
replace  tot_cp1_07=	56	if codecole==	5145522
replace  tot_cp1_07=	48	if codecole==	7163122

replace  tot_cp2_07=	44	if codecole==	1093122
replace  tot_cp2_07=	19	if codecole==	2050521
replace  tot_cp2_07=	34	if codecole==	3045522
replace  tot_cp2_07=	30	if codecole==	4131322
replace  tot_cp2_07=	66	if codecole==	5145523

replace  tot_ce_07=	118	if codecole==	1030723
replace  tot_ce_07=	19	if codecole==	1031721
replace  tot_ce_07=	49	if codecole==	1060923
replace  tot_ce_07=	19	if codecole==	1125522
replace  tot_ce_07=	10	if codecole==	2040121
replace  tot_ce_07=	19	if codecole==	2040123
replace  tot_ce_07=	26	if codecole==	2041922
replace  tot_ce_07=	9	if codecole==	2132921
replace  tot_ce_07=	50	if codecole==	2205123
replace  tot_ce_07=	68	if codecole==	4020221
replace  tot_ce_07=	17	if codecole==	4091121
replace  tot_ce_07=	48	if codecole==	4091122
replace  tot_ce_07=	56	if codecole==	5110123
replace  tot_ce_07=	7	if codecole==	5121521
replace  tot_ce_07=	4	if codecole==	7163121

replace  tot_cm1_07=	6	if codecole==	2040121
replace  tot_cm1_07=	6	if codecole==	2060723
replace  tot_cm1_07=	9	if codecole==	2132921
replace  tot_cm1_07=	25	if codecole==	2205123
replace  tot_cm1_07=	7	if codecole==	4020221
replace  tot_cm1_07=	79	if codecole==	4091123
replace  tot_cm1_07=	51	if codecole==	4091423
replace  tot_cm1_07=	13	if codecole==	5146622
replace  tot_cm1_07=	27	if codecole==	7162721
replace  tot_cm1_07=	152	if codecole==	7190423

replace  tot_cm2_07=	4	if codecole==	1092322
replace  tot_cm2_07=	98	if codecole==	1110323
replace  tot_cm2_07=	50	if codecole==	3081323
replace  tot_cm2_07=	24	if codecole==	4091123
replace  tot_cm2_07=	4	if codecole==	7162723
replace  tot_cm2_07=	62	if codecole==	7190623

drop error* inc*

**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\ecole_2e_jour"
log using "ecole codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\ecole_2e_jour"
save "ecole_cleaned_data.dta", replace
